<!--
SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

# Design of the Python Wrapper Package

The structure of the `power_grid_model` Python package is shown here below by means of the corresponding class and
package diagrams.

## Class Graph Diagram

This is the class diagram of the `power_grid_model` package.

```{note}
Only classes that have connections to other classes are shown in this diagram.
```

```{raw} html
<div style="overflow-x: auto; white-space: nowrap;">
  <img src="../_static/classes.svg" style="max-width: none;" alt="Class diagram">
</div>.
```

## Package Graph Diagram

This is the package diagram of the `power_grid_model` package.

```{note}
Only modules that import (or are imported by) other modules are shown in this diagram.
```

```{raw} html
<div style="overflow-x: auto; white-space: nowrap;">
  <img src="../_static/packages.svg" style="max-width: none;" alt="Package diagram">
</div>.
```
